@@ -225,9 +225,9 @@ class Task(abc.ABC):
     @property
     def upstream(self):
         """
-        A mapping for upstream dependencies {task name} -> [task obkect]
+        A mapping for upstream dependencies {task name} -> [task object]
         """
-        # this is jus syntactic sugar, upstream relations are tracked by the
+        # this is just syntactic sugar, upstream relations are tracked by the
         # DAG object
 
         # this always return a copy to prevent global state if contents
@@ -572,8 +572,9 @@ class Task(abc.ABC):
         except Exception as e:
             self.exec_status = TaskStatus.ErroredRender
             raise type(e)('Error rendering product from Task "{}", '
-                          ' check the full traceback above for details'.format(
-                              repr(self), self.params)) from e
+                          ' check the full traceback above for details. '
+                          'Task params: {}'.format(repr(self),
+                                                   self.params)) from e
 
         # Params are read-only for users, but we have to add the product
         # so we do it directly to the dictionary
@@ -584,8 +585,9 @@ class Task(abc.ABC):
         except Exception as e:
             self.exec_status = TaskStatus.ErroredRender
             raise type(e)('Error rendering source from Task "{}", '
-                          ' check the full traceback above for details'.format(
-                              repr(self), self.params)) from e
+                          ' check the full traceback above for details. '
+                          'Task params: {}'.format(repr(self),
+                                                   self.params)) from e
 
         # Maybe set ._exec_status directly, since no downstream propagation
         # is needed here.
